@@ -22,6 +22,7 @@ import datetime
 import time
 import platform
 import sys
+import gzip
 
 get_time = time.time
 if platform.system() == 'Windows':
@@ -33,40 +34,45 @@ def getDateTimeStamp():
     return "%d-%02.d-%02.d_%02.d-%02.d-%02.d" % (d[0], d[1], d[2], d[3], d[4], d[5])
     
 def writeHistoryFile(filename, subjectInfo):
-    if 'rin' in subjectInfo:
-        rin = subjectInfo['rin']
-        if len(rin) != 9:
-            raise Exception("The 'rin' field value must have a length of 9.")
-        eid = rin2id(rin)
-        if 'encrypted_rin' in subjectInfo and subjectInfo['encrypted_rin'] != eid:
-            raise Exception("Invalid 'encrypted_rin' value for given 'rin'.")
-        else:
-            subjectInfo['encrypted_rin'] = eid
-            subjectInfo['cipher'] = 'AES/CBC (RIJNDAEL) - 16Byte Key'
-        history = open(filename, 'w')
-        history.write(json.dumps(subjectInfo, sort_keys=True, indent=4))
-        history.close()
-    else:
-        raise Exception("The 'subjectInfo' dict must contain a 'rin' field!")
+    if not 'rin' in subjectInfo:
+        raise Exception("Can't write history file, 'rin' field missing.")
+    elif not 'encrypted_rin' in subjectInfo:
+        raise Exception("Can't write history file, 'encrypted_rin' field missing.")
+    elif not 'cipher' in subjectInfo:
+        raise Exception("Can't write history file, 'cipher' field missing.")
+    history = open(filename, 'w')
+    history.write(json.dumps(subjectInfo, sort_keys=True, indent=4))
+    history.close()
     
 class Logger():
     
-    def __init__(self, header, file=None, delim="\t", newline="\n", filler="NA"):
+    def __init__(self, header, delim="\t", newline="\n", filler="NA"):
         self.header = header
         self.delim = delim
         self.newline = newline
         self.filler = filler
+        
+    def open(self, filename, compresslevel=0):
         if file:
-            self.file = open(file, "w")
+            if self.compresslevel:
+                self.file = gzip.open("%s.gz" % filename, "w", self.compresslevel)
+            else:
+                self.file = open(filename, "w")
         else:
             self.file = sys.__stdout__
         self.file.write(self.delim.join(header))
         self.file.write(self.newline)
         
     def write(self, **kwargs):
-        line = [self.filler] * len(self.header)
-        for k, v in kwargs.iteritems():
-            if k in self.header:
-                line[self.header.index(k)] = str(v)
-        self.file.write(self.delim.join(line))
-        self.file.write(self.newline)
\ No newline at end of file
+        if self.file:
+            line = [self.filler] * len(self.header)
+            for k, v in kwargs.iteritems():
+                if k in self.header:
+                    line[self.header.index(k)] = str(v)
+            self.file.write(self.delim.join(line))
+            self.file.write(self.newline)
+        
+    def close(self):
+        if self.file != sys.__stdout__:
+            self.file.close()
+            self.file = None
\ No newline at end of file
